nxp-pac

Crates

git

Versions

mcxa256

Flavors

Ctrl2

Struct Ctrl2 

#[repr(transparent)]
pub struct Ctrl2(pub u32);
Control 2

Tuple Fields

0: u32

Implementations

Source

impl Ctrl2

pub const fn pes(&self) -> Pes

Payload Byte and Bit Order Selection

pub const fn set_pes(&mut self, val: Pes)

Payload Byte and Bit Order Selection

pub const fn asd(&self) -> Asd

ACK Suppression Disable

pub const fn set_asd(&mut self, val: Asd)

ACK Suppression Disable

pub const fn edfltdis(&self) -> Edfltdis

Edge Filter Disable

pub const fn set_edfltdis(&mut self, val: Edfltdis)

Edge Filter Disable

pub const fn isocanfden(&self) -> Isocanfden

ISO CAN FD Enable

pub const fn set_isocanfden(&mut self, val: Isocanfden)

ISO CAN FD Enable

pub const fn bte(&self) -> bool

Bit Timing Expansion Enable

pub const fn set_bte(&mut self, val: bool)

Bit Timing Expansion Enable

pub const fn prexcen(&self) -> bool

Protocol Exception Enable

pub const fn set_prexcen(&mut self, val: bool)

Protocol Exception Enable

pub const fn eacen(&self) -> Eacen

Entire Frame Arbitration Field Comparison Enable for RX Message Buffers

pub const fn set_eacen(&mut self, val: Eacen)

Entire Frame Arbitration Field Comparison Enable for RX Message Buffers

pub const fn rrs(&self) -> Rrs

Remote Request Storing

pub const fn set_rrs(&mut self, val: Rrs)

Remote Request Storing

pub const fn mrp(&self) -> Mrp

Message Buffers Reception Priority

pub const fn set_mrp(&mut self, val: Mrp)

Message Buffers Reception Priority

pub const fn tasd(&self) -> u8

Transmission Arbitration Start Delay

pub const fn set_tasd(&mut self, val: u8)

Transmission Arbitration Start Delay

pub const fn rffn(&self) -> u8

Number of Legacy Receive FIFO Filters

pub const fn set_rffn(&mut self, val: u8)

Number of Legacy Receive FIFO Filters

pub const fn boffdonemsk(&self) -> bool

Bus Off Done Interrupt Mask

pub const fn set_boffdonemsk(&mut self, val: bool)

Bus Off Done Interrupt Mask

pub const fn errmsk_fast(&self) -> bool

Error Interrupt Mask for Errors Detected in the Data Phase of Fast CAN FD Frames

pub const fn set_errmsk_fast(&mut self, val: bool)

Error Interrupt Mask for Errors Detected in the Data Phase of Fast CAN FD Frames